import React from 'react';
import PropTypes from 'prop-types';
import { Menu, Icon } from 'semantic-ui-react';

var renderSubMenu = function renderSubMenu(element) {
  if (element) {
    return React.createElement(
      Menu.Item,
      null,
      element
    );
  }
};

var Navbar = function Navbar(props) {
  var activeItem = props.activeItem,
      children = props.children,
      logo = props.logo,
      subMenu = props.subMenu,
      userMenu = props.userMenu,
      navCallback = props.navCallback;


  var items = React.Children.map(children, function (item) {
    return React.cloneElement(item, {
      active: activeItem === item.props.name
    });
  });

  return React.createElement(
    Menu,
    { className: 'navbar', borderless: true },
    React.createElement(
      Menu.Item,
      null,
      React.createElement(Icon, { name: 'angle right', size: 'large', link: true, onClick: navCallback })
    ),
    renderSubMenu(logo),
    renderSubMenu(subMenu),
    React.createElement(
      Menu.Menu,
      { position: 'right' },
      items,
      renderSubMenu(userMenu)
    )
  );
};

Navbar.propTypes = process.env.NODE_ENV !== "production" ? {
  activeItem: PropTypes.string,
  children: PropTypes.any.isRequired,
  logo: PropTypes.node,
  subMenu: PropTypes.node,
  userMenu: PropTypes.node,
  navCallback: PropTypes.func
} : {};

Navbar.defaultProps = {
  activeItem: ''
};

export default Navbar;