function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { useState } from 'react';
import PropTypes from 'prop-types';
import { Modal } from 'semantic-ui-react';

import { Button, CancelButton, SaveForm } from '../index';

var FormModal = function FormModal(_ref) {
  var open = _ref.open,
      handleSubmit = _ref.handleSubmit,
      props = _objectWithoutProperties(_ref, ['open', 'handleSubmit']);

  var cancelButton = props.cancelButton,
      children = props.children,
      defaultValues = props.defaultValues,
      formId = props.formId,
      handleChange = props.handleChange,
      saveButton = props.saveButton,
      title = props.title;

  var _useState = useState(open),
      visible = _useState[0],
      setVisible = _useState[1];

  var onSubmit = function onSubmit(values) {
    if (handleSubmit) handleSubmit(values);
    setVisible(false);
  };

  var trigger = React.cloneElement(props.trigger, {
    onClick: function onClick() {
      return setVisible(true);
    }
  });

  var save = React.cloneElement(saveButton, {
    type: 'submit',
    form: formId
  });

  var cancel = React.cloneElement(cancelButton, {
    onClick: function onClick() {
      return setVisible(false);
    }
  });

  return React.createElement(
    Modal,
    { trigger: trigger, open: visible },
    React.createElement(
      Modal.Header,
      null,
      title
    ),
    React.createElement(
      Modal.Content,
      null,
      React.createElement(
        SaveForm,
        { formId: formId, defaultValues: defaultValues, handleChange: handleChange, handleSubmit: onSubmit },
        children
      )
    ),
    React.createElement(
      Modal.Actions,
      null,
      save,
      cancel
    )
  );
};

FormModal.propTypes = process.env.NODE_ENV !== "production" ? {
  formId: PropTypes.string.isRequired,
  trigger: PropTypes.element.isRequired,
  title: PropTypes.string.isRequired,
  handleSubmit: PropTypes.func,
  handleChange: PropTypes.func,
  open: PropTypes.bool,
  defaultValues: PropTypes.shape({}),
  saveButton: PropTypes.any,
  cancelButton: PropTypes.any
} : {};

FormModal.defaultProps = {
  open: false,
  defaultValues: {},
  saveButton: React.createElement(Button, { type: 'submit', content: 'Save', icon: 'save', color: 'action-positive', inverted: true }),
  cancelButton: React.createElement(CancelButton, { inverted: true })
};

export default FormModal;