var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import BaseTable from 'react-base-table';
import AutoSizer from 'react-virtualized-auto-sizer';
import { Dimmer, Header, Loader, Segment } from 'semantic-ui-react';

export var NoDataRenderer = function NoDataRenderer() {
  return React.createElement(
    Segment,
    { textAlign: 'center' },
    React.createElement(Header, { content: 'No Data!' })
  );
};

export var LoadingFooterRenderer = function LoadingFooterRenderer() {
  return React.createElement(
    Dimmer,
    { inverted: true, active: true },
    React.createElement(Loader, { size: 'tiny', content: 'Loading more...' })
  );
};

var Table = function Table(_ref) {
  var _ref$data = _ref.data,
      data = _ref$data === undefined ? [] : _ref$data,
      _ref$widths = _ref.widths,
      widths = _ref$widths === undefined ? {} : _ref$widths,
      _ref$maxHeight = _ref.maxHeight,
      maxHeight = _ref$maxHeight === undefined ? 500 : _ref$maxHeight,
      _ref$height = _ref.height,
      height = _ref$height === undefined ? 500 : _ref$height,
      _ref$width = _ref.width,
      width = _ref$width === undefined ? 500 : _ref$width,
      _ref$noDataHeight = _ref.noDataHeight,
      noDataHeight = _ref$noDataHeight === undefined ? 100 : _ref$noDataHeight,
      _ref$footerHeight = _ref.footerHeight,
      footerHeight = _ref$footerHeight === undefined ? 50 : _ref$footerHeight,
      _ref$responsive = _ref.responsive,
      responsive = _ref$responsive === undefined ? false : _ref$responsive,
      _ref$loading = _ref.loading,
      loading = _ref$loading === undefined ? false : _ref$loading,
      onFetch = _ref.onFetch,
      children = _ref.children,
      rest = _objectWithoutProperties(_ref, ['data', 'widths', 'maxHeight', 'height', 'width', 'noDataHeight', 'footerHeight', 'responsive', 'loading', 'onFetch', 'children']);

  var _useState = useState(loading),
      isLoading = _useState[0],
      setLoading = _useState[1];

  useEffect(function () {
    return setLoading(loading);
  }, [loading]);

  var onEndReached = function onEndReached() {
    if (onFetch) {
      if (!isLoading) {
        onFetch();
        setLoading(true);
      }
    }
  };

  var props = {
    fixed: true,
    data: data,
    maxHeight: data.length === 0 ? undefined : maxHeight,
    height: data.length === 0 ? noDataHeight : undefined,
    footerHeight: isLoading ? footerHeight : 0,
    footerRenderer: LoadingFooterRenderer,
    emptyRenderer: NoDataRenderer,
    onEndReached: onEndReached
  };

  if (responsive) {
    return React.createElement(
      AutoSizer,
      { disableHeight: true },
      function (_ref2) {
        var autoWidth = _ref2.width;

        return React.createElement(
          BaseTable,
          _extends({ width: autoWidth }, props, rest),
          children
        );
      }
    );
  }

  return React.createElement(
    BaseTable,
    _extends({ width: width }, props, rest),
    children
  );
};

export { Table };
Table.propTypes = process.env.NODE_ENV !== "production" ? {
  data: PropTypes.arrayOf(PropTypes.shape({})),
  maxHeight: PropTypes.number,
  height: PropTypes.number,
  width: PropTypes.number,
  noDataHeight: PropTypes.number,
  footerHeight: PropTypes.number,
  responsive: PropTypes.bool,
  loading: PropTypes.bool,
  onFetch: PropTypes.func,
  children: PropTypes.arrayOf(PropTypes.object)
} : {};

export default Table;