'use strict';

exports.__esModule = true;
exports.clinGenCondition = exports.clinGenHGNCGene = exports.alamutEntry = exports.orphanetEntry = exports.hpoEntry = exports.omimSearch = exports.omimEntry = exports.hgmdGene = exports.hgmdVariant = exports.decipherRegionSearch = exports.decipherVariant = exports.gnomadGeneEntry = exports.exacGeneEntry = exports.gtexEntry = exports.geneReviewsEntry = exports.hgncEntry = exports.ghrEntry = exports.geneCardsEntry = exports.dgvRegionSearch = exports.ucscLocus = exports.gnomadVariant = exports.exacVariant = exports.ensemblLocus = exports.cosmicEntry = exports.clinvarEntry = exports.clinvarSearch = exports.variationViewer = exports.pubmedEntry = exports.pubmedSearch = exports.esearch = exports.esummary = exports.efetch = undefined;

var _lodash = require('lodash');

var _genomicsUrls = require('../constants/genomics-urls');

var urls = _interopRequireWildcard(_genomicsUrls);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

// NCBI APIs
var efetch = exports.efetch = function efetch(db, id) {
  var retmode = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'xml';
  var params = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';
  return urls.NCBI_EFETCH_ENDPOINT + '?retmode=' + retmode + '&db=' + db + '&id=' + id + '&' + params;
};

var esummary = exports.esummary = function esummary(db, id) {
  var retmode = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'json';
  var params = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';
  return urls.NCBI_ESUMMARY_ENDPOINT + '?retmode=' + retmode + '&db=' + db + '&id=' + id + '&' + params;
};

var esearch = exports.esearch = function esearch(db, term) {
  var retmode = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'json';
  var params = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';
  return urls.NCBI_ESEARCH_ENDPOINT + '?retmode=' + retmode + '&db=' + db + '&term=' + term + '&' + params;
};

// NCBI URLs
var pubmedSearch = exports.pubmedSearch = function pubmedSearch(term) {
  return urls.PUBMED_URL + '/?term=' + term;
};

var pubmedEntry = exports.pubmedEntry = function pubmedEntry(pmid) {
  return urls.PUBMED_URL + '/' + pmid;
};

var variationViewer = exports.variationViewer = function variationViewer(chr, start, end) {
  var assembly = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'GCF_000001405.25';
  return urls.NCBI_VARIATION_URL + '/?assm=' + assembly + '&chr=' + chr + '&from=' + start + '&to=' + end;
};

var clinvarSearch = exports.clinvarSearch = function clinvarSearch(term) {
  return urls.CLINVAR_URL + '/?term=' + term;
};

var clinvarEntry = exports.clinvarEntry = function clinvarEntry(id) {
  return urls.CLINVAR_URL + '/variation/' + id;
};

// Genomic URLs
var cosmicEntry = exports.cosmicEntry = function cosmicEntry(id) {
  var trimmedId = (0, _lodash.trimStart)(id, 'COSM');
  return urls.COSMIC_URL + '/mutation/overview?id=' + trimmedId;
};

var ensemblLocus = exports.ensemblLocus = function ensemblLocus(chr, start, end) {
  var genome = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'grch37';
  var species = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 'Homo_sapiens';

  var url = void 0;

  // TODO: This should be switched to a lookup object sicne genome and species are so related

  if (['hg19', 'grch37'].includes((0, _lodash.toLower)(genome))) {
    url = '' + urls.ENSEMBL_GRCH37_URL;
  } else if (['hg38', 'grch38'].includes((0, _lodash.toLower)(genome))) {
    url = '' + urls.ENSEMBL_GRCH38_URL;
  } else {
    throw new Error('genome: ' + genome + ' not supported!');
  }

  return url + '/' + species + '/Location/View?db=core;r=' + chr + ':' + start + '-' + end;
};

var exacVariant = exports.exacVariant = function exacVariant(chr, pos, ref, alt) {
  return urls.EXAC_URL + '/variant/' + chr + '-' + pos + '-' + ref + '-' + alt;
};

var gnomadVariant = exports.gnomadVariant = function gnomadVariant(chr, pos, ref, alt) {
  return urls.GNOMAD_URL + '/variant/' + chr + '-' + pos + '-' + ref + '-' + alt;
};

var ucscLocus = exports.ucscLocus = function ucscLocus(chr, start, end) {
  var genome = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'hg19';
  return urls.UCSC_URL + '/cgi-bin/hgTracks?db=' + genome + '&position=chr' + chr + ':' + start + '-' + end;
};

var dgvRegionSearch = exports.dgvRegionSearch = function dgvRegionSearch(chr, start, end) {
  return urls.DGV_URL + '/gb2/gbrowse/dgv2_hg19/?name=chr' + chr + ':' + start + '-' + end + ';search=Search';
};

// Gene Resources
var geneCardsEntry = exports.geneCardsEntry = function geneCardsEntry(gene) {
  return urls.GENE_CARDS_URL + '/cgi-bin/carddisp.pl?gene=' + gene;
};

var ghrEntry = exports.ghrEntry = function ghrEntry(gene) {
  return urls.GHR_URL + '/gene/' + gene;
};

var hgncEntry = exports.hgncEntry = function hgncEntry(gene) {
  return urls.HGNC_URL + '/cgi-bin/search?search_type=all&search=' + gene;
};

var geneReviewsEntry = exports.geneReviewsEntry = function geneReviewsEntry(gene) {
  return urls.GENEREVIEWS_URL + '/?term=' + gene;
};

var gtexEntry = exports.gtexEntry = function gtexEntry(gene) {
  return urls.GTEX_URL + '/home/gene/' + gene;
};

var exacGeneEntry = exports.exacGeneEntry = function exacGeneEntry(gene) {
  return urls.EXAC_URL + '/gene/' + gene;
};

var gnomadGeneEntry = exports.gnomadGeneEntry = function gnomadGeneEntry(gene) {
  return urls.GNOMAD_URL + '/gene/' + gene;
};

// Clinical Resources
var decipherVariant = exports.decipherVariant = function decipherVariant(chr, start, end) {
  return urls.DECIPHER_URL + '/search?q=' + chr + ':' + start + '-' + end + '#consented-patients/results';
};

var decipherRegionSearch = exports.decipherRegionSearch = function decipherRegionSearch(chr, start, end) {
  return urls.DECIPHER_URL + '/search?q=chr' + chr + ':' + start + '-' + end + '#consented-patients/results';
};

var hgmdVariant = exports.hgmdVariant = function hgmdVariant(cdna) {
  return urls.HGMD_URL + '/hgmd/pro/mut.php?acc=' + cdna;
};

var hgmdGene = exports.hgmdGene = function hgmdGene(gene) {
  return urls.HGMD_URL + '/hgmd/pro/gene.php?gene=' + gene;
};

var omimEntry = exports.omimEntry = function omimEntry(id) {
  return urls.OMIM_URL + '/entry/' + id;
};

var omimSearch = exports.omimSearch = function omimSearch(term) {
  return urls.OMIM_URL + '/search/?index=entry&search=' + term;
};

// Phenotype Resources
var hpoEntry = exports.hpoEntry = function hpoEntry(id) {
  if ((0, _lodash.startsWith)(id, 'HP:')) {
    return urls.HPO_URL + '/hpoweb/showterm?id=' + id;
  } else {
    var hpoId = (0, _lodash.padStart)(id, 7, '0');
    return urls.HPO_URL + '/hpoweb/showterm?id=HP:' + hpoId;
  }
};

var orphanetEntry = exports.orphanetEntry = function orphanetEntry(id) {
  return urls.ORPHANET_URL + '/consor/cgi-bin/OC_Exp.php?Lng=EN&Expert=' + id;
};

// Internal Resources
var alamutEntry = exports.alamutEntry = function alamutEntry(cdna) {
  return urls.ALAMUT_URL + '/show?request=' + cdna;
};

// ClinGen urls
var clinGenHGNCGene = exports.clinGenHGNCGene = function clinGenHGNCGene(hgncId) {
  return urls.CLINGEN_URL + '/genes/HGNC:' + hgncId;
};
var clinGenCondition = exports.clinGenCondition = function clinGenCondition(mondoId) {
  return urls.CLINGEN_URL + '/conditions/MONDO_' + mondoId;
};